@@ -8,12 +8,14 @@
 #' Pull files from the NEON API, by data product, merge data for each table, and read into the current R environment
 #'
 #' @param dpID The identifier of the NEON data product to pull, in the form DPL.PRNUM.REV, e.g. DP1.10023.001
-#' @param site Either the string 'all', or the four-letter code of a single NEON site, e.g. 'CLBJ'. Future versions may allow more options for subsetting than one or all sites. Defaults to all.
+#' @param site Either the string 'all', meaning all available sites, or a character vector of 4-letter NEON site codes, e.g. c('ONAQ','RMNP'). Defaults to all.
 #' @param startdate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA.
 #' @param enddate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA.
 #' @param package Either 'basic' or 'expanded', indicating which data package to download. Defaults to basic.
 #' @param avg Either the string 'all', or the averaging interval to download, in minutes. Only applicable to sensor (IS) data. Defaults to 'all'.
-#' @param check.size T or F, should the user be told the total file size before downloading? Defaults to T. When working in batch mode, or other non-interactive workflow, use check.size=F.
+#' @param check.size T or F, should the user approve the total file size before downloading? Defaults to T. When working in batch mode, or other non-interactive workflow, use check.size=F.
+#' @param nCores The number of cores to parallelize the stacking procedure. By default it is set to a single core.
+#' @param forceParallel If the data volume to be processed does not meet minimum requirements to run in parallel, this overrides. Set to FALSE as default.
 
 #' @details All available data meeting the query criteria will be downloaded. Most data products are collected at only a subset of sites, and dates of collection vary. Consult the NEON data portal for sampling details.
 #' Dates are specified only to the month because NEON data are provided in monthly packages. Any month included in the search criteria will be included in the download. Start and end date are inclusive.
@@ -37,7 +39,7 @@
 ##############################################################################################
 
 loadByProduct <- function(dpID, site="all", startdate=NA, enddate=NA, package="basic", 
-                          avg="all", check.size=TRUE) {
+                          avg="all", check.size=TRUE, nCores=1, forceParallel=FALSE) {
   
   # error message if package is not basic or expanded
   if(!package %in% c("basic", "expanded")) {
@@ -45,7 +47,7 @@ loadByProduct <- function(dpID, site="all", startdate=NA, enddate=NA, package="b
   }
 
   # error message if dpID isn't formatted as expected
-  if(regexpr("DP[1-4]{1}.[0-9]{5}.001",dpID)!=1) {
+  if(regexpr("DP[1-4]{1}.[0-9]{5}.001", dpID)!=1) {
     stop(paste(dpID, "is not a properly formatted data product ID. The correct format is DP#.#####.001", sep=" "))
   }
   
@@ -64,13 +66,12 @@ loadByProduct <- function(dpID, site="all", startdate=NA, enddate=NA, package="b
   
   # pass the request to zipsByProduct() to download
   zipsByProduct(dpID=dpID, site=site, startdate=startdate, enddate=enddate, package=package, 
-                avg=avg, check.size=check.size, savepath=temppath, load=T)
+                avg=avg, check.size=check.size, savepath=temppath, load=TRUE)
   
   # stack and load the downloaded files using stackByTable
   out <- stackByTable(filepath=paste(temppath, "/filesToStack", substr(dpID, 5, 9), sep=""), 
-                      savepath="envt", folder=T)
+                      savepath="envt", folder=TRUE, nCores, forceParallel)
+  # Remove temppath directory
+  unlink(temppath)
   return(out)
-
-}
-
-
+  }
\ No newline at end of file
