@@ -11,10 +11,11 @@ makes_files <- function(object, output, expected) {
     )
 }
 
+f <- file.path(tempdir(), "output_gp")
 test_that("Test that correct files are created for microbe group abundances", {
   makes_files(stackByTable(system.file("extdata", "NEON_gp.zip", 
-                                   package="neonUtilities")),
-              system.file("extdata", "NEON_gp/stackedFiles", package="neonUtilities"),
+                                   package="neonUtilities"), savepath=f),
+              paste(f, "stackedFiles", sep="/"),
               system.file("extdata", "expected/gp", package="neonUtilities"))
 })
 
